@@ -30,12 +30,14 @@ my $sample = {
     baz => 789,
   },
   readonly => \2,
+  boolean => [1 == 1, 1 == 2],
   regexp => qr/foo.*bar/i,
   glob   => \*STDOUT,
   code   => sub { return 42 },
   class  => $obj,
 };
 
+
 $sample->{weakref} = $sample;
 weaken $sample->{weakref};
 
@@ -52,3 +54,4 @@ use DDP show_memsize  => 1,
 p $sample, theme => 'Material' , as => 'Material theme:';
 p $sample, theme => 'Solarized', as => 'Solarized theme:';
 p $sample, theme => 'Monokai', as => 'Monokai theme:';
+p $sample, theme => 'Classic', as => 'Classic pre-1.0 theme:';
