@@ -1,6 +1,6 @@
 package Data::Printer::Theme::Material;
 # inspired by Mattia Astorino's Material theme:
-# https://github.com/equinusocio/vsc-material-theme
+# https://github.com/material-theme/vsc-material-theme
 use strict;
 use warnings;
 
@@ -8,10 +8,7 @@ sub colors {
     my %code_for = (
         'very_light_gray' =>  '#EEFFFF',
         'light_gray'      =>  '#A1BBC5',
-        'middle_gray'     =>  '#808080',
-        'gray'            =>  '#373b41',
-        'dark_gray'       =>  '#282a2e',
-        'very_dark_gray'  =>  '#263238',
+        'gray'            =>  '#4f5a61',
         'green'           =>  '#90B55A', #'#C3E88D',
         'teal'            =>  '#009688',
         'light_teal'      =>  '#73d1c8',
@@ -40,8 +37,10 @@ sub colors {
         vstring     => $code_for{strong_orange},  # version strings (v5.16.0, etc)
         lvalue      => $code_for{strong_orange},  # lvalue label
         format      => $code_for{strong_orange},  # format type
+        true        => $code_for{blue},           # boolean type (true)
+        false       => $code_for{blue},           # boolean type (false)
         repeated    => $code_for{red},  # references to seen values
-        caller_info => $code_for{very_dark_gray},  # details on what's being printed
+        caller_info => $code_for{gray},  # details on what's being printed
         weak        => $code_for{green},  # weak references flag
         tainted     => $code_for{light_orange},  # tainted flag
         unicode     => $code_for{light_orange},  # utf8 flag
